#! /bin/sh
# $Id: install_wrapper.sh,v 1.16 2000/07/04 15:59:30 ajosey Exp $
#
# A simple shell wrapper to simplify installation.
# This can also be used for multiple installations
# Run this script by sh install_wrapper
# 
# Change History
#
#
# $Log: install_wrapper.sh,v $
# Revision 1.16  2000/07/04 15:59:30  ajosey
# update the INCDIRS variable in SRC/install/params.data/Linux just in case its different
#
# Revision 1.15  2000/07/04 15:55:42  ajosey
# add in check for pax in PATH
#
# Revision 1.14  2000/07/04 07:21:43  ajosey
# add in /sbin to the PATH
#
# Revision 1.13  2000/06/28 09:03:14  cyeoh
# Asks if user wants to build/run tests and subsequently optionally rerun
# failed and unresolved tests
#
# Revision 1.11  2000/05/29 08:15:35  ajosey
# update additional tetexec.cfg params
#
# Revision 1.10  2000/04/10 15:22:23  ajosey
# exclude VSX_PATH from parameter update into tetexec.cfg
#
# Revision 1.9  2000/04/10 07:46:44  ajosey
# rework the editing of the template tetexec.cfg file
#
# Revision 1.8  2000/04/10 06:47:08  ajosey
# auto tune the mountable filesystem params in tetexec.cfg
#
# Revision 1.7  2000/04/10 06:08:54  ajosey
# add in new userintf.c file with ext2 and UNIX98 pseudotty support
#
# Revision 1.6  2000/04/09 08:06:55  ajosey
# add in auto detection of the #include directories
#
# Revision 1.5  2000/04/07 08:36:44  ajosey
# remove double message at the end
#
# Revision 1.4  2000/04/07 08:18:35  ajosey
# enhance the script to edit the uids/gids into tetexec.cfg
#
# Revision 1.3  2000/04/07 08:06:04  ajosey
# the tetexec.cfg file is now in the LSB.tools/vsx4 subdirectory
#
# Revision 1.2  2000/04/07 07:39:21  ajosey
# tidy up output
#
# Revision 1.1  2000/04/07 07:31:57  ajosey
# redo  install wrapper using printf, so should work with bash
#
#
#
##########################################################

DEFAULT=linux
INSTDIR=${TET_ROOT}/vsx4
PATH=$PATH:$INSTDIR/BIN
TOOLDIR=${TET_ROOT}/LSB.tools
export PATH TOOLSDIR
cd $INSTDIR
VSXDIR="$HOME/SRC"
CURDIR=$VSXDIR

if test ! -d "$VSXDIR/install"
then
        printf "*** VSX must be installed in your HOME directory ($HOME)\n"
        exit 1
fi

cat - <<!EOF
**********************************************************
**		    The Open Group			**
**		   Verification Suite			**
**	Configuration Procedure for Linux		**
**********************************************************
!EOF


printf "Locating header file #include directories...\n"
printf "Calling: gcc -print-file-name=include/stddef.h\n"
STDDEF=`gcc -print-file-name="include/stddef.h"`
if [  $? -eq 0 ]
then 
    INCDIR=`dirname $STDDEF`
    printf "INCDIRS=\"$INCDIR /usr/include\"\n"
    printf "INCDIRS=\"$INCDIR /usr/include\"\n" >>SRC/vsxparams
    printf "INCDIRS=\"$INCDIR /usr/include\"\n" >>SRC/install/params.data/Linux
else
    printf "Defaulting to /usr/include\n"
fi

if test ! -f "loopback_disk.ext2"
then
    printf "Note: To use a loopback mounted disk you must have the option\n"
    printf "compiled into your kernel.\n"
    printf "Create loopback disk? [y] \c"
    read cmd
    if [ "$cmd" = "Y" -o "$cmd" = "y" -o "$cmd" = "" ] ; then
	dd if=/dev/zero of=loopback_disk.ext2 bs=1k count=2000
	/sbin/mke2fs -F loopback_disk.ext2
    fi
fi

if test -f "loopback_disk.ext2"
then
# Configure loopback disk 
    printf "Setup loopback disk? [y] \c"
    read cmd
    if [ "$cmd" = "Y" -o "$cmd" = "y" -o "$cmd" = "" ] ; then
	printf "Enter loopback device to use [/dev/loop0]"
	read cmd
	if [ "$cmd" = "" ] ; then
	    cmd=/dev/loop0
	fi
	printf "Enter the root password:\n"
	su root -c "PATH=$PATH:/sbin losetup $cmd loopback_disk.ext2"
    fi
fi

printf "Run config.sh ..? [y] \c"
read cmd
if [ "$cmd" = "Y" -o "$cmd" = "y" -o "$cmd" = "" ] ; then
	config.sh
fi

printf "\n----------------------------------------------------------\n"

printf "Completed config.sh. Now patching vsxconfig.h ...\n"
cp $TOOLDIR/vsxconfig.h SRC/vsxconfig.h

printf "Update SRC/userintf.c for ext2 filesystem and UNIX98 pseudottys..? [y] \c"
read cmd
if [ "$cmd" = "Y" -o "$cmd" = "y" -o "$cmd" = "" ] ; then
	cp $TOOLDIR/vsx4/userintf.c SRC/userintf.c
fi

printf "** Assuming no wide character support ** \n"
printf "Installing wc_nosup.cfg into SRC/wchars.cfg\n"
cp SRC/wc_nosup.cfg SRC/wchars.cfg


printf "\n----------------------------------------------------------\n"

printf "Install pseudolanguages ..? [y] \c"
read cmd
if [ "$cmd" = "Y" -o "$cmd" = "y" -o "$cmd" = "" ] ; then
	printf "Enter the root password:\n"
	su root -c "cd $TOOLDIR/psldefs && make"
fi

printf "\n----------------------------------------------------------\n"

cd $INSTDIR
printf "Building the test framework ... enter the root password\n"
su root -c make

printf "\n----------------------------------------------------------\n"

. $CURDIR/vsxparams

export VSXDIR TEST_MODE TEST_XNFS SUBSETS INCDIRS CC COPTS THR_COPTS
export DEFINES LDFLAGS SYSLIBS CURDIR PATH TET_EXECUTE NOSPC_DEV
export VSX_OPER VSX_ORG VSX_SYS

printf "Install scripts into TESTROOT/BIN..? [y] \c"
read cmd
if [ "$cmd" = "Y" -o "$cmd" = "y" -o "$cmd" = "" ] ; then
	chmod u+w $TET_EXECUTE/BIN/*.sh
	cp $TOOLDIR/tbin/*.sh $TET_EXECUTE/BIN/
	which pax 2>&1 >/dev/null
	if [ $? -ne 0 ]
	then
	   printf "Warning: no pax utility found, needed by dataform tests\n"
	fi
fi


printf "Install tetexec.cfg ..? [y] \c"
read cmd
if [ "$cmd" = "Y" -o "$cmd" = "y" -o "$cmd" = "" ] ; then


	cp /dev/null .newparams
	
echo "VSX_OPER=\"$VSX_OPER\"" >>.newparams
echo "VSX_ORG=\"$VSX_ORG\"" >>.newparams
echo "VSX_SYS=\"$VSX_SYS\"" >>.newparams
echo "TEST_MODE=\"$TEST_MODE\"" >>.newparams
echo "VSX_CC=\"$CC\"" >> .newparams
echo "VSX_CFLAGS=\"$COPTS\"" >> .newparams
echo "VSX_LIBS=\"$MLIB $SYSLIBS $LDFLAGS\"" >> .newparams
echo "VSX_MOUNT_DEV=\"$NOSPC_DEV\"" >> .newparams
echo "VSX_NOSPC_DEV=\"$NOSPC_DEV\"" >> .newparams
echo "VSX_ROFS=\"$NOSPC_DEV\"" >> .newparams
echo "VSX_INVALID_GID=unsup" >> .newparams
echo "VSX_INVALID_UID=unsup" >> .newparams
echo "VSX_INVALID_PGID=unsup" >> .newparams


	grep vsx1 /etc/passwd 2>&1 >/dev/null
	if [ $? -eq 1 ]
	then
		printf "Warning: it appears as if the uids and gids are not correctly installed proceeding anyway..."
	else
		VSX_UID0=`grep vsx0 /etc/passwd|cut -d: -f3`
		VSX_GID0=`grep vsx0 /etc/passwd|cut -d: -f4`
		VSX_UID1=`grep vsx1 /etc/passwd|cut -d: -f3`
		VSX_GID1=`grep vsx1 /etc/passwd|cut -d: -f4`
		VSX_UID2=`grep vsx2 /etc/passwd|cut -d: -f3`
		VSX_GID2=`grep vsx2 /etc/passwd|cut -d: -f4`

		printf "VSX_UID0=$VSX_UID0\n" >>.newparams
		printf "VSX_UID1=$VSX_UID1\n" >>.newparams
		printf "VSX_UID2=$VSX_UID2\n" >>.newparams
		printf "VSX_GID0=$VSX_GID0\n" >>.newparams
		printf "VSX_GID1=$VSX_GID1\n" >>.newparams
		printf "VSX_GID2=$VSX_GID2\n" >>.newparams
	fi

	cat $TOOLDIR/vsx4/tetexec.cfg|$VSXDIR/install/scripts/editcfg.sh .newparams > $TET_EXECUTE/tetexec.cfg
	rm -f .newparams

fi

PATH=$PATH:$INSTDIR/BIN:${TET_ROOT}/bin
printf "Build and execute the suite now ..? [y] \c"
read cmd
if [ "$cmd" = "Y" -o "$cmd" = "y" -o "$cmd" = "" ] ; then
	echo "running, tccb -p; tcce -p; jx"
	tcc -p -b -s $HOME/scen.bld $*
	tcc -p -e -s $HOME/scen.exec $*
	(cd $HOME/results; awk -f `which vres` `ls -d 0* | tail -1`/journal)
	printf "A formal report (vrpt) has been saved in $HOME/results/report\n"
	(cd $HOME/results; vrpt `ls -d 0* | tail -1`/journal >$HOME/results/report)
fi

printf "Rerun just the failures (produces a journal of only fails) ..? [y] \c"
read cmd
if [ "$cmd" = "Y" -o "$cmd" = "y" -o "$cmd" = "" ] ; then
	JNL=`ls -d $HOME/results/0* | tail -1`
	JNLDIR=`basename $JNL`
	echo "running tcc -p -e -s scen.exec -r FAIL,UNRESOLVED,UNINITIATED results/$JNLDIR/journal"
	cd ; tcc -p -e -s scen.exec -r FAIL,UNRESOLVED,UNINITIATED results/$JNLDIR/journal
fi

printf "That's all folks...\n"
